from __future__ import annotations
from typing import Any
from numpy.typing import NDArray
from numpy import arange, float64


def interpolate_abciss(signals: tuple[Signal, ...]) -> NDArray[float64]:
    """
    return the axis that would be used by the interpolate function
    """
    rates: list[float] = [signal.rate for signal in signals]

    start: float = max([signal.x[0] for signal in signals])
    end: float = min([signal.x[-1] for signal in signals])

    return arange(start, end, 1 / max(rates))


def interpolate(signals: tuple[Signal, ...]) -> tuple[Signal, ...]:
    """
    Interpolate multiple signals with a single abciss list, which has
    the smallest interval and the bigget rate
    """
    splines = [signal.spline() for signal in signals]

    x = interpolate_abciss(signals)

    new_signals = [
        Signal(x, spline(x), signals[0].settings) for spline in splines
    ]

    return tuple(new_signals)


from backscattering_analyzer.signal import Signal  # no circular import
